import json

# ----------------------------------------------------------------------------------------------------------------------
# Obtaining a list of universities and related data on them
import requests
from requests_utils import request_call


def get_universities(url):
    result = request_call(url, 200)
    if isinstance(result, requests.exceptions.RequestException):
        return result
    content = result.content
    print(result)
    my_json = content.decode('utf8').replace("'", '"')
    # Load the JSON to a Python list
    universities_list = json.loads(my_json)
    return universities_list

# universities_url = 'http://universities.hipolabs.com/search?country=Israel'
# universities = get_universities(universities_url)
# print(universities)



import requests


# ----------------------------------------------------------------------------------------------------------------------
# Generic function to http requests
def request_call(url, status_code):
    response = None
    try:
        response = requests.get(url)
        if response.status_code == status_code:
            return response
        else:
            raise requests.exceptions.RequestException("the status code does not matched, check your url")
    except requests.exceptions.RequestException as e:
        return e



from setuptools import setup

with open("README.md","r") as fh:
    long_description = fh.read()

setup(
    name='universities_exercise_api_v1',
    version='0.0.3',
    description='A simple api for working with universities data',
    py_modules=['universities_api', 'requests_utils'],
    package_dir={'': 'src'},
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.8',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent'
    ],
    install_requires=['requests>=2.25.1'],
    url='https://github.com/omerl2322/pip_package_exercise',
    author='Omer Levy',
    author_email='omerl2322@gmail.com',
    long_description=long_description,
    long_description_content_type='text/markdown'

)
